@@ -4,7 +4,6 @@
 @LastEditTime: 2020-04-26 15:11:04
 @LastEditors: Please set LastEditors
 @Description: 优惠券券包接口
-@FilePath: \cd_api\cdApi\coupon_pack.py
 '''
 
 from .base import base
@@ -15,7 +14,7 @@ class couponPack(base):
         super().__init__(token)
 
     def list(self, pageNum=1, pageSize=10):
-        api_name = "manager/coupon/list"
+        api_name = "manager/coupon_pack/list"
         data = {
             "pageNum": pageNum,
             "pageSize": pageSize,
@@ -28,16 +27,12 @@ class couponPack(base):
             "id": _id,
         }
         response = self.request(api_name, data, method="GET")
-        # print(response)
         return self.response(response)
 
     def update(self, data):
         api_name = "manager/coupon_pack/update"
         response = self.request(api_name, data, method="POST")
-        print(response)
-        # return self.response(response)
+        return self.response(response)
 
     def delete(self):
         pass
-
-
