@@ -1,7 +1,4 @@
 '''
-@Author: Rqk
-@Date: 2020-04-26 15:01:20
-@Description: 
 @说明    :商品素材接口。
 @时间    :2020/2/13 下午4:28:26
 @作者    :任秋锴
